@@ -188,11 +188,11 @@ module Rabbit
           end
         end
 
-        def attach_to(window)
+        def attach_to(window, container=nil)
           super
 
           init_menu
-          add_widget_to_window(@window)
+          add_widgets_to_container(@container)
           widget.show
           attach_menu(@window)
           attach_key(@window)
@@ -203,8 +203,7 @@ module Rabbit
           detach_menu(@window)
           widget.hide
           unless @window.destroyed?
-            remove_widget_from_window(@window)
-            @window.signal_handler_disconnect(@configure_signal_id)
+            remove_widgets_from_container(@container)
           end
 
           super
@@ -297,12 +296,12 @@ module Rabbit
         end
 
         private
-        def add_widget_to_window(window)
-          window.add(@embed)
+        def add_widgets_to_container(container)
+          container.add(@embed)
         end
 
-        def remove_widget_from_window(window)
-          window.remove(@embed)
+        def remove_widgets_from_container(container)
+          container.remove(@embed)
         end
 
         def init_dpi
